@@ -12,7 +12,7 @@ use Alien::Build::Plugin::Download::Negotiate;
 use Alien::Build::Plugin::Extract::Negotiate;
 
 # ABSTRACT: Alien::Build plugin to download from GitHub
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 has github_user => sub { croak("github_user is required") };
@@ -51,24 +51,10 @@ sub init
   {
     if(defined $ENV{$name})
     {
-      if(eval { Alien::Build->VERSION("2.39") })
-      {
-        $secret = $ENV{$name};
-        push @{ $gh_fetch_options{http_headers} }, Authorization => "token $secret";
-        Alien::Build->log("using the GitHub Personal Access Token in $name") if $once;
-        $once = 0;
-      }
-      else
-      {
-        if($once)
-        {
-          Alien::Build->log("You seem to have a GitHub Personal Access Token stored in $name.");
-          Alien::Build->log("Unfortunately, the version of Alien::Build you have doesn't support");
-          Alien::Build->log("sending http headers so I can't use it.  Please upgrade to Alien::Build");
-          Alien::Build->log("2.39 or better.");
-          $once = 1;
-        }
-      }
+      $secret = $ENV{$name};
+      push @{ $gh_fetch_options{http_headers} }, Authorization => "token $secret";
+      Alien::Build->log("using the GitHub Personal Access Token in $name") if $once;
+      $once = 0;
       last;
     }
   }
@@ -116,9 +102,20 @@ sub init
         }
         my $version_key = $res->{filename} eq 'releases' ? 'tag_name' : 'name';
 
-        return {
-          type => 'list',
-          list => [
+        if($ENV{ALIEN_BUILD_PLUGIN_DOWNLOAD_GITHUB_DEBUG})
+        {
+          require YAML;
+          my $url = $url || $meta->prop->{start_url};
+          $url = URI->new($url);
+          $build->log(YAML::Dump({
+            url => $url->path,
+            res => $rel,
+          }));
+        }
+
+        my $res2 = {
+          type     => 'list',
+          list     => [
             map {
               my $release = $_;
               my($version) = $release->{$version_key} =~ $self->version;
@@ -143,6 +140,9 @@ sub init
             } @$rel
           ],
         };
+
+        $res2->{protocol} = $res->{protocol} if exists $res->{protocol};
+        return $res2;
       }
       else
       {
@@ -177,7 +177,7 @@ Alien::Build::Plugin::Download::GitHub - Alien::Build plugin to download from Gi
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -286,6 +286,9 @@ make sure that your PAT is not displayed in the log.
 
 =head1 CAVEATS
 
+This plugin does not support, and will not work if C<ALIEN_DOWNLOAD_RULE> is set to
+either C<digest_and_encrypt> or C<digest>.
+
 The GitHub API is rate limited.  Once you've reach that limit, this plugin will be 
 inoperative for a period of time until the limits reset.  When using the GitHub
 API unauthenticated the limit is especially low.  This is usually not a problem when
@@ -332,7 +335,7 @@ Roy Storey (KIWIROY)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Graham Ollis.
+This software is copyright (c) 2019-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
